@@ -8,7 +8,7 @@ from qolab.hardware.basic import BasicInstrument
 import re
 
 class SDS2304X(SDS1104X):
-    """ Siglent SDS2354x scope """
+    """ Siglent SDS2304x scope """
     vertDivOnScreen = 8 # unlike SDS1104X, number of divisions matches what is seen on the screen
     horizDivOnScreen = 10
     def __init__(self, resource, *args, **kwds):
@@ -26,8 +26,6 @@ class SDS2304X(SDS1104X):
         # Siglent claims that this model should have same commands as SDS1104X
         # however response is different, for example we got '2.00E-08S' instead 'TDIV 2.00E-08S'
         # expected reply to query: '2.00E-08S' 
-        spltStr=re.split('S', rstr)
-        numberString = spltStr[0]
-        #prefix, numberString, unit = response2numStr(rstr, firstSeparator=None, unit='S')
+        prefix, numberString, unit = response2numStr(rstr, firstSeparator=None, unit='S')
         return(float(numberString))
 
